Learn R Programming

mar1s (version 2.1.1)

nesterov.index: Nesterov index in Irkutsk region, USSR: historical data

Description

Values of Nesterov index in 6 distincts of Irkutsk region, USSR + region averaged. Daily from April 01 to October 31, 1969--1991 (total 4708 observations).

Usage

data(nesterov.index)

Arguments

Format

A multivariate time series.

Details

The Nesterov index is the official Russian fire-danger rating specified by standard GOST R 22.1.09--99. It is calculated using the ignition index, the temperature, the dew-point temperature and the number of days since last significant (\(\ge 3 mm\)) precipitation.

The dataset consists of daily values 1969--1991.

Examples

Run this code
# NOT RUN {
data(nesterov.index)
colnames(nesterov.index)
plot(nesterov.index)
# }

Run the code above in your browser using DataLab